weixinpay
============

.. image:: https://img.shields.io/pypi/v/weixinpay.svg
    :target: https://pypi.python.org/pypi/weixinpay

.. image:: https://img.shields.io/pypi/wheel/weixinpay.svg
    :target: https://pypi.python.org/pypi/weixinpay

.. image:: https://img.shields.io/pypi/status/weixinpay.svg
    :target: https://pypi.python.org/pypi/weixinpay

.. image:: https://img.shields.io/pypi/l/weixinpay.svg
    :target: https://pypi.python.org/pypi/weixinpay

微信支付 Python 库.


提供接口
--------

- 统一下单
- 带签名的客户端支付信息
- 订单查询
- 异步通知验证
- 异步通知请求解析


安装
------

.. code-block:: bash

    $ pip install weixinpay


License
=========

Copyright (C) 2016 TaoBeier
